pub fn simple_layout(
parent: LayoutNode,
count: usize,
style: &Style,
) -> Vec<LayoutNode>Expand description
Lay out count children of equal size inside parent.
pub fn simple_layout(
parent: LayoutNode,
count: usize,
style: &Style,
) -> Vec<LayoutNode>Lay out count children of equal size inside parent.